@@ -1,3 +1,5 @@
+/* $Id: acconfig.h,v 1.7 1998/10/13 20:44:34 roessler Exp $ */
+
 /* Is this the international version? */
 #undef SUBVERSION
 
@@ -10,9 +12,6 @@
 /* Where to put l10n data */
 #undef MUTTLOCALEDIR
 
-/* Where to put other shared data */
-#undef SHAREDIR
-
 /* Enable debugging info */
 #define DEBUG
 
