@@ -1,3 +1,4 @@
+static char rcsid[]="$Id: addrbook.c,v 1.10 1998/10/13 20:44:35 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -125,7 +126,6 @@ void mutt_alias_menu (char *buf, size_t buflen, ALIAS *aliases)
   int t = -1;
   int i, done = 0;
   char helpstr[SHORT_STRING];
-  int savedmenu = CurrentMenu;
 
   if (!aliases)
   {
@@ -140,7 +140,7 @@ void mutt_alias_menu (char *buf, size_t buflen, ALIAS *aliases)
   menu->make_entry = alias_entry;
   menu->search = alias_search;
   menu->tag = alias_tag;
-  menu->menu = CurrentMenu = MENU_ALIAS;
+  menu->menu = MENU_ALIAS;
   menu->title = _("Aliases");
   menu->help = mutt_compile_help (helpstr, sizeof (helpstr), MENU_ALIAS, AliasHelp);
 
@@ -189,6 +189,5 @@ void mutt_alias_menu (char *buf, size_t buflen, ALIAS *aliases)
     rfc822_write_address (buf, buflen, AliasTable[t]->addr);
   
   mutt_menuDestroy (&menu);
-  CurrentMenu = savedmenu;
   safe_free ((void **) &AliasTable);
 }
