@@ -1,3 +1,4 @@
+static char rcsid[]="$Id: browser.c,v 1.12 1998/10/13 20:44:39 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -465,7 +466,6 @@ void mutt_select_file (char *f, size_t flen, int buffy)
   MUTTMENU *menu;
   struct stat st;
   int i, killPrefix = 0;
-  int savedmenu = CurrentMenu;
 
   memset (&state, 0, sizeof (struct browser_state));
 
@@ -516,7 +516,7 @@ void mutt_select_file (char *f, size_t flen, int buffy)
     return;
 
   menu = mutt_new_menu ();
-  menu->menu = CurrentMenu = MENU_FOLDER;
+  menu->menu = MENU_FOLDER;
   menu->make_entry = folder_entry;
   menu->search = select_file_search;
   menu->title = title;
@@ -625,7 +625,6 @@ void mutt_select_file (char *f, size_t flen, int buffy)
 
 	destroy_state (&state);
 	mutt_menuDestroy (&menu);
-	CurrentMenu = savedmenu;
 	return;
 
       case OP_BROWSER_TELL:
@@ -664,7 +663,6 @@ void mutt_select_file (char *f, size_t flen, int buffy)
 		mutt_error _("Error scanning directory.");
 		destroy_state (&state);
 		mutt_menuDestroy (&menu);
-		CurrentMenu = savedmenu;
 		return;
 	      }
 	    }
@@ -721,7 +719,6 @@ void mutt_select_file (char *f, size_t flen, int buffy)
 	    {
 	      mutt_error _("Error scanning directory.");
 	      mutt_menuDestroy (&menu);
-	      CurrentMenu = savedmenu;
 	      return;
 	    }
 	    killPrefix = 0;
@@ -818,7 +815,6 @@ void mutt_select_file (char *f, size_t flen, int buffy)
 	  strfcpy (f, buf, flen);
 	  destroy_state (&state);
 	  mutt_menuDestroy (&menu);
-	  CurrentMenu = savedmenu;
 	  return;
 	}
 	MAYBE_REDRAW (menu->redraw);
