@@ -1,3 +1,4 @@
+static char rcsid[]="$Id: commands.c,v 1.13 1998/10/13 22:53:15 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -238,9 +239,11 @@ void ci_bounce_message (HEADER *h, int *redraw)
   ADDRESS *adr = NULL;
   int rc;
 
-  /* FIXME i18n */
-  snprintf (prompt, sizeof(prompt), "Bounce %smessage%s to: ",
-	    h ? "" : "tagged ", h ? "" : "s");
+  if(h)
+    strfcpy(prompt, _("Bounce message to: "), sizeof(prompt));
+  else
+    strfcpy(prompt, _("Bounce tagged messages to: "), sizeof(prompt));
+  
   rc = mutt_get_field (prompt, buf, sizeof (buf), M_ALIAS);
 
   if (option (OPTNEEDREDRAW))
