@@ -1,3 +1,4 @@
+static char rcsid[]="$Id: compose.c,v 1.22 1998/10/13 20:44:49 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -438,12 +439,11 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
   /* Sort, SortAux could be changed in mutt_index_menu() */
   int oldSort = Sort, oldSortAux = SortAux;
   struct stat st;
-  int savedmenu = CurrentMenu;
 
   idx = mutt_gen_attach_list (msg->content, idx, &idxlen, &idxmax, 0, 1);
 
   menu = mutt_new_menu ();
-  menu->menu = CurrentMenu = MENU_COMPOSE;
+  menu->menu = MENU_COMPOSE;
   menu->offset = HDR_ATTACH;
   menu->max = idxlen;
   menu->make_entry = snd_entry;
@@ -1109,7 +1109,6 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
   }
 
   mutt_menuDestroy (&menu);
-  CurrentMenu = savedmenu;
 
   if (idxlen)
   {
