@@ -1,3 +1,4 @@
+static char rcsid[]="$Id: curs_main.c,v 1.21 1998/10/13 20:44:54 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -255,10 +256,9 @@ int mutt_index_menu (void)
   int do_buffy_notify = 1;
   int close = 0; /* did we OP_QUIT or OP_EXIT out of this menu? */
   int attach_msg = option(OPTATTACHMSG);
-  int savedmenu = CurrentMenu;
 
   menu = mutt_new_menu ();
-  menu->menu = CurrentMenu = MENU_MAIN;
+  menu->menu = MENU_MAIN;
   menu->offset = 1;
   menu->pagelen = LINES - 3;
   menu->make_entry = index_make_entry;
@@ -477,27 +477,22 @@ int mutt_index_menu (void)
       {
 	timeout (Timeout * 1000); /* milliseconds */      
 	event = mutt_getch ();
-	dprint(1, (debugfile, "mutt_index_menu[%d]: Got event (%d, %d)\n", __LINE__,
+	dprint(4, (debugfile, "mutt_index_menu[%d]: Got event (%d, %d)\n", __LINE__,
 		   event.ch, event.op));
 	timeout (-1); /* restore blocking operation */
-	if (event.ch != -1)
+	op = event.ch;
+	if (op != -1)
 	{
-	  dprint(1, (debugfile, "mutt_index_menu[%d]: Pushing event (%d, %d)\n", __LINE__,
+	  dprint(4, (debugfile, "mutt_index_menu[%d]: Pushing event (%d, %d)\n", __LINE__,
 		     event.ch, event.op));
 	  mutt_ungetch (event.ch, event.op);
 	  op = km_dokey (MENU_MAIN);
-	  dprint(1, (debugfile, "mutt_index_menu[%d]: Got op %d\n", __LINE__,
-		     op));
 	}
-	else
-	  op = -1;
       }
       else
-      {
 	op = km_dokey (MENU_MAIN);
-	dprint(1, (debugfile, "mutt_index_menu[%d]: Got op %d\n", __LINE__,
-		   op));
-      }
+
+      dprint(4, (debugfile, "mutt_index_menu[%d]: Got op %d\n", __LINE__, op));
 
       mutt_curs_set (1);
       
@@ -507,7 +502,7 @@ int mutt_index_menu (void)
 	mutt_flushinp ();
 	mutt_resize_screen ();
 	menu->redraw = REDRAW_FULL;
-	menu->menu = CurrentMenu = MENU_MAIN;
+	menu->menu = MENU_MAIN;
 	Signals &= ~S_SIGWINCH;
 	menu->top = 0; /* so we scroll the right amount */
 	continue;
@@ -972,7 +967,7 @@ int mutt_index_menu (void)
 	  menu->redraw = REDRAW_INDEX | REDRAW_STATUS;
 	}
 
-	menu->menu = CurrentMenu = MENU_PAGER;
+	menu->menu = MENU_PAGER;
 	menu->oldcurrent = menu->current;
 	continue;
 
@@ -1722,7 +1717,7 @@ int mutt_index_menu (void)
 
     if (menu->menu == MENU_PAGER)
     {
-      menu->menu = CurrentMenu = MENU_MAIN;
+      menu->menu = MENU_MAIN;
       menu->redraw = REDRAW_FULL;
       set_option (OPTWEED); /* turn header weeding back on. */
     }
@@ -1731,7 +1726,6 @@ int mutt_index_menu (void)
   }
 
   mutt_menuDestroy (&menu);
-  CurrentMenu = savedmenu;
   return (close);
 }
 
