@@ -1,3 +1,4 @@
+static char rcsid[]="$Id: enter.c,v 1.11 1998/10/13 20:45:00 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -416,9 +417,12 @@ int mutt_enter_string (unsigned char *buf, size_t buflen, int y, int x,
 	case OP_EDITOR_QUOTE_CHAR:
 	  ADDCH (LastKey);
 	  event = mutt_getch ();
-	  LastKey = event.ch;
-	  move (y, x + curpos - begin);
-	  goto self_insert;
+	  if(event.ch != -1)
+	  {
+	    LastKey = event.ch;
+	    move (y, x + curpos - begin);
+	    goto self_insert;
+	  }
 
 	default:
 	  BEEP ();
