@@ -1,3 +1,4 @@
+static char rcsid[]="$Id: pgpkey.c,v 1.8 1998/10/13 20:45:52 roessler Exp $";
 /*
  * Copyright (C) 1996,1997 Michael R. Elkins <me@cs.hmc.edu>
  * Copyright (c) 1998 Thomas Roessler <roessler@guug.de>
@@ -123,7 +124,6 @@ static KEYINFO *pgp_select_key (struct pgp_vinfo *pgp,
   FILE *fp, *devnull;
   pid_t thepid;
   KEYINFO *info;
-  int savedmenu = CurrentMenu;
   
   
   for (i = 0, l = keys; l; l = l->next)
@@ -185,7 +185,7 @@ static KEYINFO *pgp_select_key (struct pgp_vinfo *pgp,
   menu->max = keymax;
   menu->make_entry = pgp_entry;
   menu->search = pgp_search;
-  menu->menu = CurrentMenu = MENU_PGP;
+  menu->menu = MENU_PGP;
   menu->help = helpstr;
   menu->data = KeyTable;
 
@@ -283,7 +283,6 @@ static KEYINFO *pgp_select_key (struct pgp_vinfo *pgp,
   }
 
   mutt_menuDestroy (&menu);
-  CurrentMenu = savedmenu;
   safe_free ((void **) &KeyTable);
 
   return (info);
