@@ -1,3 +1,4 @@
+static char rcsid[]="$Id: postpone.c,v 1.12 1998/10/13 20:45:56 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -103,11 +104,10 @@ static HEADER *select_msg (void)
   MUTTMENU *menu;
   int i, done=0, r=-1;
   char helpstr[SHORT_STRING];
-  int savedmenu = CurrentMenu;
 
   menu = mutt_new_menu ();
   menu->make_entry = post_entry;
-  menu->menu = CurrentMenu = MENU_POST;
+  menu->menu = MENU_POST;
   menu->max = PostContext->msgcount;
   menu->title = _("Postponed Messages");
   menu->data = PostContext;
@@ -149,7 +149,6 @@ static HEADER *select_msg (void)
   }
 
   mutt_menuDestroy (&menu);
-  CurrentMenu = savedmenu;
   return (r > -1 ? PostContext->hdrs[r] : NULL);
 }
 
