@@ -1,3 +1,4 @@
+static char rcsid[]="$Id: query.c,v 1.10 1998/10/13 20:45:58 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -240,7 +241,6 @@ static void query_menu (char *buf, size_t buflen, QUERY *results, int retbuf)
   int op;
   char helpstr[SHORT_STRING];
   char title[STRING];
-  int savedmenu = CurrentMenu;
 
   snprintf (title, sizeof (title), _("Query")); /* FIXME */
 
@@ -248,7 +248,7 @@ static void query_menu (char *buf, size_t buflen, QUERY *results, int retbuf)
   menu->make_entry = query_entry;
   menu->search = query_search;
   menu->tag = query_tag;
-  menu->menu = CurrentMenu = MENU_QUERY;
+  menu->menu = MENU_QUERY;
   menu->title = title;
   menu->help = mutt_compile_help (helpstr, sizeof (helpstr), MENU_QUERY, QueryHelp);
 
@@ -464,5 +464,4 @@ static void query_menu (char *buf, size_t buflen, QUERY *results, int retbuf)
   }
 
   mutt_menuDestroy (&menu);
-  CurrentMenu = savedmenu;
 }
