@@ -1,3 +1,4 @@
+static char rcsid[]="$Id: recvattach.c,v 1.19 1998/10/13 22:53:22 roessler Exp $";
 /*
  * Copyright (C) 1996-1998 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -610,9 +611,12 @@ static void query_bounce_attachment (int tag, BODY *top, HEADER *hdr)
   int rc;
 
   buf[0] = 0;
-  /* FIXME i18n */
-  snprintf (prompt, sizeof (prompt), "Bounce %smessage%s to: ",
-	    tag ? "tagged " : "", tag ? "s" : "");
+
+  if(!tag)
+    strfcpy(prompt, _("Bounce message to: "), sizeof(prompt));
+  else
+    strfcpy(prompt, _("Bounce tagged messages to: "), sizeof(prompt));
+
   rc = mutt_get_field (prompt, buf, sizeof (buf), M_ALIAS);
 
   if (rc || !buf[0])
@@ -809,7 +813,6 @@ void mutt_view_attachments (HEADER *hdr)
   short idxmax = 0;
   int flags = 0;
   int op;
-  int savedmenu = CurrentMenu;
   
   /* make sure we have parsed this message */
   mutt_parse_mime_message (Context, hdr);
@@ -848,7 +851,7 @@ void mutt_view_attachments (HEADER *hdr)
   menu->max = idxlen;
   menu->make_entry = attach_entry;
   menu->tag = mutt_tag_attach;
-  menu->menu = CurrentMenu = MENU_ATTACH;
+  menu->menu = MENU_ATTACH;
   menu->title = _("Attachments");
   menu->data = idx;
   menu->help = mutt_compile_help (helpstr, sizeof (helpstr), MENU_ATTACH, AttachHelp);
@@ -1044,7 +1047,6 @@ void mutt_view_attachments (HEADER *hdr)
 
 
 	mutt_menuDestroy  (&menu);
-	CurrentMenu = savedmenu;
 	return;
     }
   }
