@@ -1,3 +1,4 @@
+static char rcsid[]="$Id: sendlib.c,v 1.22 1998/10/13 20:46:11 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -589,7 +590,7 @@ static int lookup_mime_type (char *d, const char *s)
   cur_sze = 0;
   szf = strlen (s);
 
-  for (count = 0 ; count < 2 ; count++)
+  for (count = 0 ; count < 3 ; count++)
   {
     /*
      * can't use strtok() because we use it in an inner loop below, so use
@@ -601,6 +602,9 @@ static int lookup_mime_type (char *d, const char *s)
 	snprintf (buf, sizeof (buf), "%s/.mime.types", NONULL(Homedir));
 	break;
       case 1:
+        strfcpy (buf, SYSCONFDIR"/mime.types", sizeof(buf));
+        break;
+      case 2:
 	strfcpy (buf, SHAREDIR"/mime.types", sizeof (buf));
 	break;
       default:
